@@ -67,6 +67,7 @@ typedef enum {
 	GS_PLUGIN_LOADER_ACTION_INSTALL,
 	GS_PLUGIN_LOADER_ACTION_REMOVE,
 	GS_PLUGIN_LOADER_ACTION_SET_RATING,
+	GS_PLUGIN_LOADER_ACTION_UPGRADE,
 	GS_PLUGIN_LOADER_ACTION_LAST
 } GsPluginLoaderAction;
 
@@ -104,8 +105,6 @@ GList		*gs_plugin_loader_get_sources_finish	(GsPluginLoader	*plugin_loader,
 							 GError		**error);
 void		 gs_plugin_loader_get_popular_async	(GsPluginLoader	*plugin_loader,
 							 GsPluginRefineFlags flags,
-							 const gchar	*category,
-							 const gchar	*category_exclude,
 							 GCancellable	*cancellable,
 							 GAsyncReadyCallback callback,
 							 gpointer	 user_data);
