@@ -125,12 +125,6 @@ typedef gboolean	 (*GsPluginCategoryFunc)	(GsPlugin	*plugin,
 							 GList		**list,
 							 GCancellable	*cancellable,
 							 GError		**error);
-typedef gboolean	 (*GsPluginPopularFunc)		(GsPlugin	*plugin,
-							 GList		**list,
-							 const gchar	*category,
-							 const gchar	*category_exclude,
-							 GCancellable	*cancellable,
-							 GError		**error);
 typedef gboolean	 (*GsPluginResultsFunc)		(GsPlugin	*plugin,
 							 GList		**list,
 							 GCancellable	*cancellable,
@@ -175,9 +169,6 @@ void		 gs_plugin_list_randomize		(GList		**list);
 void		 gs_plugin_status_update		(GsPlugin	*plugin,
 							 GsApp		*app,
 							 GsPluginStatus	 status);
-void		 gs_plugin_progress_update		(GsPlugin	*plugin,
-							 GsApp		*app,
-							 guint		 percentage);
 void		 gs_plugin_updates_changed		(GsPlugin	*plugin);
 const gchar	*gs_plugin_status_to_string		(GsPluginStatus	 status);
 gboolean	 gs_plugin_add_search			(GsPlugin	*plugin,
@@ -223,8 +214,6 @@ gboolean	 gs_plugin_add_category_apps		(GsPlugin	*plugin,
 							 GError		**error);
 gboolean	 gs_plugin_add_popular			(GsPlugin	*plugin,
 							 GList		**list,
-							 const gchar	*category,
-							 const gchar	*category_exclude,
 							 GCancellable	*cancellable,
 							 GError		**error);
 gboolean	 gs_plugin_add_featured			(GsPlugin	*plugin,
@@ -252,6 +241,10 @@ gboolean	 gs_plugin_app_set_rating		(GsPlugin	*plugin,
 							 GsApp		*app,
 							 GCancellable	*cancellable,
 							 GError		**error);
+gboolean	 gs_plugin_app_upgrade			(GsPlugin	*plugin,
+							 GsApp		*app,
+							 GCancellable	*cancellable,
+							 GError		**error);
 gboolean	 gs_plugin_refresh			(GsPlugin	*plugin,
 							 guint		 cache_age,
 							 GsPluginRefreshFlags flags,
