@@ -230,16 +230,15 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 				 SoupMessage *msg,
 				 gpointer user_data)
 {
-	_cleanup_object_unref_ GsScreenshotImage *ssimg = GS_SCREENSHOT_IMAGE (user_data);
-	GsScreenshotImagePrivate *priv = gs_screenshot_image_get_instance_private (ssimg);
+	GsScreenshotImagePrivate *priv;
 	gboolean ret;
 	_cleanup_error_free_ GError *error = NULL;
 	_cleanup_object_unref_ AsImage *im = NULL;
 	_cleanup_object_unref_ GdkPixbuf *pixbuf = NULL;
 	_cleanup_object_unref_ GInputStream *stream = NULL;
+	_cleanup_object_unref_ GsScreenshotImage *ssimg = GS_SCREENSHOT_IMAGE (user_data);
 
-	/* return immediately if the message was cancelled or if we're in destruction */
-	if (msg->status_code == SOUP_STATUS_CANCELLED || priv->session == NULL)
+	if (msg->status_code == SOUP_STATUS_CANCELLED)
 		return;
 
 	if (msg->status_code != SOUP_STATUS_OK) {
@@ -250,6 +249,8 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 		return;
 	}
 
+	priv = gs_screenshot_image_get_instance_private (ssimg);
+
 	/* create a buffer with the data */
 	stream = g_memory_input_stream_new_from_data (msg->response_body->data,
 						      msg->response_body->length,
@@ -447,7 +448,7 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 	/* download file */
 	g_debug ("downloading %s to %s", url, priv->filename);
 	base_uri = soup_uri_new (url);
-	if (base_uri == NULL || !SOUP_URI_VALID_FOR_HTTP (base_uri)) {
+	if (base_uri == NULL) {
 		/* TRANSLATORS: this is when we try to download a screenshot
 		 * that was not a valid URL */
 		gs_screenshot_image_set_error (ssimg, _("Screenshot not valid"));
