@@ -34,7 +34,6 @@
 #include "gs-app-addon-row.h"
 #include "gs-history-dialog.h"
 #include "gs-screenshot-image.h"
-#include "gs-progress-button.h"
 #include "gs-star-widget.h"
 
 static void	gs_shell_details_finalize	(GObject	*object);
@@ -251,16 +250,6 @@ gs_shell_details_switch_to (GsShellDetails *shell_details)
 		}
 	}
 
-	/* do a fill bar for the current progress */
-	switch (gs_app_get_state (priv->app)) {
-	case AS_APP_STATE_INSTALLING:
-		gs_progress_button_set_show_progress (GS_PROGRESS_BUTTON (priv->button_install), TRUE);
-		break;
-	default:
-		gs_progress_button_set_show_progress (GS_PROGRESS_BUTTON (priv->button_install), FALSE);
-		break;
-	}
-
 	/* spinner */
 	if (kind == GS_APP_KIND_SYSTEM) {
 		gtk_widget_set_visible (priv->spinner_install_remove, FALSE);
@@ -274,10 +263,10 @@ gs_shell_details_switch_to (GsShellDetails *shell_details)
 		case AS_APP_STATE_UPDATABLE:
 		case AS_APP_STATE_UNAVAILABLE:
 		case AS_APP_STATE_AVAILABLE_LOCAL:
-		case AS_APP_STATE_INSTALLING:
 			gtk_widget_set_visible (priv->spinner_install_remove, FALSE);
 			gtk_spinner_stop (GTK_SPINNER (priv->spinner_install_remove));
 			break;
+		case AS_APP_STATE_INSTALLING:
 		case AS_APP_STATE_REMOVING:
 			gtk_spinner_start (GTK_SPINNER (priv->spinner_install_remove));
 			gtk_widget_set_visible (priv->spinner_install_remove, TRUE);
@@ -295,27 +284,6 @@ gs_shell_details_switch_to (GsShellDetails *shell_details)
 	gs_grab_focus_when_mapped (priv->scrolledwindow_details);
 }
 
-static gboolean
-gs_shell_details_refresh_progress_idle (gpointer user_data)
-{
-	GsShellDetails *shell_details = GS_SHELL_DETAILS (user_data);
-	GsShellDetailsPrivate *priv = shell_details->priv;
-
-	gs_progress_button_set_progress (GS_PROGRESS_BUTTON (priv->button_install),
-	                                 gs_app_get_progress (priv->app));
-
-	g_object_unref (shell_details);
-	return G_SOURCE_REMOVE;
-}
-
-static void
-gs_shell_details_progress_changed_cb (GsApp *app,
-                                      GParamSpec *pspec,
-                                      GsShellDetails *shell_details)
-{
-	g_idle_add (gs_shell_details_refresh_progress_idle, g_object_ref (shell_details));
-}
-
 static gboolean
 gs_shell_details_switch_to_idle (gpointer user_data)
 {
@@ -721,11 +689,6 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 		break;
 	}
 
-	/* don't show the launch button if the app doesn't have a desktop ID */
-	tmp = gs_app_get_id (priv->app);
-	if (tmp == NULL)
-		gtk_widget_set_visible (priv->button_details_launch, FALSE);
-
 	/* make history button insensitive if there is none */
 	history = gs_app_get_history (priv->app);
 	switch (gs_app_get_id_kind (priv->app)) {
@@ -779,7 +742,12 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 	switch (gs_app_get_kind (priv->app)) {
 	case GS_APP_KIND_NORMAL:
 	case GS_APP_KIND_SYSTEM:
-		gtk_widget_set_visible (priv->infobar_details_app_norepo, tmp == NULL && gs_app_get_state (priv->app) == AS_APP_STATE_AVAILABLE_LOCAL);
+		if (gs_app_get_id_kind (priv->app) == AS_ID_KIND_FIRMWARE) {
+			gtk_widget_set_visible (priv->infobar_details_app_norepo, FALSE);
+		} else {
+			gtk_widget_set_visible (priv->infobar_details_app_norepo,
+						tmp == NULL && gs_app_get_state (priv->app) == AS_APP_STATE_AVAILABLE_LOCAL);
+		}
 		break;
 	default:
 		gtk_widget_set_visible (priv->infobar_details_app_norepo, FALSE);
@@ -916,12 +884,8 @@ gs_shell_details_filename_to_app_cb (GObject *source,
 	_cleanup_error_free_ GError *error = NULL;
 	_cleanup_free_ gchar *tmp = NULL;
 
-	/* save app */
-	if (priv->app != NULL) {
-		g_signal_handlers_disconnect_by_func (priv->app, gs_shell_details_notify_state_changed_cb, shell_details);
-		g_signal_handlers_disconnect_by_func (priv->app, gs_shell_details_progress_changed_cb, shell_details);
+	if (priv->app != NULL)
 		g_object_unref (priv->app);
-	}
 	priv->app = gs_plugin_loader_filename_to_app_finish(plugin_loader,
 							    res,
 							    &error);
@@ -947,6 +911,7 @@ gs_shell_details_filename_to_app_cb (GObject *source,
 		return;
 	}
 
+	/* save app */
 	g_signal_connect_object (priv->app, "notify::state",
 				 G_CALLBACK (gs_shell_details_notify_state_changed_cb),
 				 shell_details, 0);
@@ -956,9 +921,6 @@ gs_shell_details_filename_to_app_cb (GObject *source,
 	g_signal_connect_object (priv->app, "notify::licence",
 				 G_CALLBACK (gs_shell_details_notify_state_changed_cb),
 				 shell_details, 0);
-	g_signal_connect_object (priv->app, "notify::progress",
-				 G_CALLBACK (gs_shell_details_progress_changed_cb),
-				 shell_details, 0);
 
 	/* print what we've got */
 	tmp = gs_app_to_string (priv->app);
@@ -1035,11 +997,8 @@ gs_shell_details_set_app (GsShellDetails *shell_details, GsApp *app)
 	gs_shell_details_set_state (shell_details, GS_SHELL_DETAILS_STATE_LOADING);
 
 	/* save app */
-	if (priv->app != NULL) {
-		g_signal_handlers_disconnect_by_func (priv->app, gs_shell_details_notify_state_changed_cb, shell_details);
-		g_signal_handlers_disconnect_by_func (priv->app, gs_shell_details_progress_changed_cb, shell_details);
+	if (priv->app != NULL)
 		g_object_unref (priv->app);
-	}
 	priv->app = g_object_ref (app);
 	g_signal_connect_object (priv->app, "notify::state",
 				 G_CALLBACK (gs_shell_details_notify_state_changed_cb),
@@ -1050,9 +1009,6 @@ gs_shell_details_set_app (GsShellDetails *shell_details, GsApp *app)
 	g_signal_connect_object (priv->app, "notify::licence",
 				 G_CALLBACK (gs_shell_details_notify_state_changed_cb),
 				 shell_details, 0);
-	g_signal_connect_object (priv->app, "notify::progress",
-				 G_CALLBACK (gs_shell_details_progress_changed_cb),
-				 shell_details, 0);
 	gs_shell_details_load (shell_details);
 
 	/* change widgets */
@@ -1147,16 +1103,12 @@ gs_shell_details_app_launch_button_cb (GtkWidget *widget, GsShellDetails *shell_
 	_cleanup_object_unref_ GAppLaunchContext *context = NULL;
 
 	desktop_id = gs_app_get_id (shell_details->priv->app);
-	if (desktop_id == NULL) {
-		g_warning ("no such desktop file: %s", desktop_id);
-		return;
-	}
+	display = gdk_display_get_default ();
 	appinfo = G_APP_INFO (g_desktop_app_info_new (desktop_id));
 	if (appinfo == NULL) {
 		g_warning ("no such desktop file: %s", desktop_id);
 		return;
 	}
-	display = gdk_display_get_default ();
 	context = G_APP_LAUNCH_CONTEXT (gdk_display_get_app_launch_context (display));
 	if (!g_app_info_launch (appinfo, NULL, context, &error))
 		g_warning ("launching %s failed: %s", desktop_id, error->message);
@@ -1364,8 +1316,7 @@ gs_shell_details_init (GsShellDetails *shell_details)
 	/* setup networking */
 	priv->session = soup_session_sync_new_with_options (SOUP_SESSION_USER_AGENT,
 							    "gnome-software",
-							    SOUP_SESSION_TIMEOUT, 60,
-							    SOUP_SESSION_IDLE_TIMEOUT, 60,
+							    SOUP_SESSION_TIMEOUT, 5000,
 							    NULL);
 	if (priv->session != NULL) {
 		soup_session_add_feature_by_type (priv->session,
@@ -1392,11 +1343,8 @@ gs_shell_details_finalize (GObject *object)
 	g_object_unref (priv->builder);
 	g_object_unref (priv->plugin_loader);
 	g_object_unref (priv->cancellable);
-	if (priv->app != NULL) {
-		g_signal_handlers_disconnect_by_func (priv->app, gs_shell_details_notify_state_changed_cb, shell_details);
-		g_signal_handlers_disconnect_by_func (priv->app, gs_shell_details_progress_changed_cb, shell_details);
+	if (priv->app != NULL)
 		g_object_unref (priv->app);
-	}
 	if (priv->session != NULL)
 		g_object_unref (priv->session);
 
