@@ -48,6 +48,7 @@ struct GsShellOverviewPrivate
 	gboolean		 loading_popular_rotating;
 	gboolean		 loading_categories;
 	gboolean		 empty;
+	gchar			*category_of_day;
 
 	GtkWidget		*bin_featured;
 	GtkWidget		*box_overview;
@@ -71,6 +72,21 @@ enum {
 
 static guint signals [SIGNAL_LAST] = { 0 };
 
+typedef struct {
+        GsCategory	*category;
+        GsShellOverview	*shell_overview;
+} LoadData;
+
+static void
+load_data_free (LoadData *data)
+{
+        if (data->category != NULL)
+                g_object_unref (data->category);
+        if (data->shell_overview != NULL)
+                g_object_unref (data->shell_overview);
+        g_slice_free (LoadData, data);
+}
+
 /**
  * gs_shell_overview_invalidate:
  **/
@@ -90,6 +106,14 @@ popular_tile_clicked (GsPopularTile *tile, gpointer data)
 	gs_shell_show_app (shell->priv->shell, app);
 }
 
+static gboolean
+filter_category (GsApp *app, gpointer user_data)
+{
+	const gchar *category = (const gchar *) user_data;
+
+	return !gs_app_has_category (app, category);
+}
+
 /**
  * gs_shell_overview_get_popular_cb:
  **/
@@ -117,6 +141,9 @@ gs_shell_overview_get_popular_cb (GObject *source_object,
 			g_warning ("failed to get popular apps: %s", error->message);
 		goto out;
 	}
+	/* Don't show apps from the category that's currently featured as the category of the day */
+	gs_plugin_list_filter (&list, filter_category, priv->category_of_day);
+	gs_plugin_list_randomize (&list);
 
 	gs_container_remove_all (GTK_CONTAINER (priv->box_popular));
 
@@ -125,7 +152,7 @@ gs_shell_overview_get_popular_cb (GObject *source_object,
 		tile = gs_popular_tile_new (app);
 		g_signal_connect (tile, "clicked",
 			  G_CALLBACK (popular_tile_clicked), shell);
-		gtk_box_pack_start (GTK_BOX (priv->box_popular), tile, TRUE, TRUE, 0);
+		gtk_container_add (GTK_CONTAINER (priv->box_popular), tile);
 	}
 
 	priv->empty = FALSE;
@@ -145,7 +172,8 @@ gs_shell_overview_get_popular_rotating_cb (GObject *source_object,
 					   GAsyncResult *res,
 					   gpointer user_data)
 {
-	GsShellOverview *shell = GS_SHELL_OVERVIEW (user_data);
+	LoadData *load_data = (LoadData *) user_data;
+	GsShellOverview *shell = load_data->shell_overview;
 	GsShellOverviewPrivate *priv = shell->priv;
 	GsPluginLoader *plugin_loader = GS_PLUGIN_LOADER (source_object);
 	GList *l;
@@ -156,7 +184,7 @@ gs_shell_overview_get_popular_rotating_cb (GObject *source_object,
 	_cleanup_error_free_ GError *error = NULL;
 
 	/* get popular apps */
-	list = gs_plugin_loader_get_popular_finish (plugin_loader, res, &error);
+	list = gs_plugin_loader_get_category_apps_finish (plugin_loader, res, &error);
 	if (list == NULL) {
 		if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
 			g_warning ("failed to get recommended applications: %s", error->message);
@@ -169,6 +197,7 @@ gs_shell_overview_get_popular_rotating_cb (GObject *source_object,
 		gtk_widget_hide (priv->box_popular_rotating);
 		goto out;
 	}
+	gs_plugin_list_randomize (&list);
 
 	gtk_widget_show (priv->popular_rotating_heading);
 	gtk_widget_show (priv->box_popular_rotating);
@@ -180,13 +209,14 @@ gs_shell_overview_get_popular_rotating_cb (GObject *source_object,
 		tile = gs_popular_tile_new (app);
 		g_signal_connect (tile, "clicked",
 			  G_CALLBACK (popular_tile_clicked), shell);
-		gtk_box_pack_start (GTK_BOX (priv->box_popular_rotating), tile, TRUE, TRUE, 0);
+		gtk_container_add (GTK_CONTAINER (priv->box_popular_rotating), tile);
 	}
 
 	priv->empty = FALSE;
 
 out:
 	gs_plugin_list_free (list);
+	load_data_free (load_data);
 	priv->loading_popular_rotating = FALSE;
 	priv->refresh_count--;
 	if (priv->refresh_count == 0) {
@@ -227,6 +257,9 @@ gs_shell_overview_get_featured_cb (GObject *source_object,
 			g_warning ("failed to get featured apps: %s", error->message);
 		goto out;
 	}
+	/* Don't show apps from the category that's currently featured as the category of the day */
+	gs_plugin_list_filter (&list, filter_category, priv->category_of_day);
+	gs_plugin_list_randomize (&list);
 
 	/* at the moment, we only care about the first app */
 	app = GS_APP (list->data);
@@ -349,6 +382,8 @@ gs_shell_overview_load (GsShellOverview *shell_overview)
 		g_assert_not_reached ();
 		break;
 	}
+	g_free (priv->category_of_day);
+	priv->category_of_day = g_strdup (category_of_day);
 
 	if (!priv->loading_featured) {
 		priv->loading_featured = TRUE;
@@ -364,8 +399,6 @@ gs_shell_overview_load (GsShellOverview *shell_overview)
 		priv->loading_popular = TRUE;
 		gs_plugin_loader_get_popular_async (priv->plugin_loader,
 						    GS_PLUGIN_REFINE_FLAGS_DEFAULT,
-						    NULL,
-						    category_of_day,
 						    priv->cancellable,
 						    gs_shell_overview_get_popular_cb,
 						    shell_overview);
@@ -373,14 +406,24 @@ gs_shell_overview_load (GsShellOverview *shell_overview)
 	}
 
 	if (!priv->loading_popular_rotating) {
+		LoadData *load_data;
+		_cleanup_object_unref_ GsCategory *category = NULL;
+		_cleanup_object_unref_ GsCategory *featured_category = NULL;
+
+		category = gs_category_new (NULL, category_of_day, NULL);
+		featured_category = gs_category_new (category, "featured", NULL);
+
+		load_data = g_slice_new0 (LoadData);
+		load_data->category = g_object_ref (category);
+		load_data->shell_overview = g_object_ref (shell_overview);
+
 		priv->loading_popular_rotating = TRUE;
-		gs_plugin_loader_get_popular_async (priv->plugin_loader,
-						    GS_PLUGIN_REFINE_FLAGS_DEFAULT,
-						    category_of_day,
-						    NULL,
-						    priv->cancellable,
-						    gs_shell_overview_get_popular_rotating_cb,
-						    shell_overview);
+		gs_plugin_loader_get_category_apps_async (priv->plugin_loader,
+		                                          featured_category,
+		                                          GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+		                                          priv->cancellable,
+		                                          gs_shell_overview_get_popular_rotating_cb,
+		                                          load_data);
 		priv->refresh_count++;
 	}
 
@@ -469,10 +512,10 @@ gs_shell_overview_setup (GsShellOverview *shell_overview,
 
 	for (i = 0; i < N_TILES; i++) {
 		tile = gs_popular_tile_new (NULL);
-		gtk_box_pack_start (GTK_BOX (priv->box_popular), tile, TRUE, TRUE, 0);
+		gtk_container_add (GTK_CONTAINER (priv->box_popular), tile);
 
 		tile = gs_popular_tile_new (NULL);
-		gtk_box_pack_start (GTK_BOX (priv->box_popular_rotating), tile, TRUE, TRUE, 0);
+		gtk_container_add (GTK_CONTAINER (priv->box_popular_rotating), tile);
 	}
 
 	/* chain up */
@@ -499,6 +542,7 @@ gs_shell_overview_finalize (GObject *object)
 	g_object_unref (priv->builder);
 	g_object_unref (priv->plugin_loader);
 	g_object_unref (priv->cancellable);
+	g_free (priv->category_of_day);
 
 	G_OBJECT_CLASS (gs_shell_overview_parent_class)->finalize (object);
 }
