@@ -34,7 +34,6 @@
 #include "gs-markdown.h"
 #include "gs-update-dialog.h"
 #include "gs-update-list.h"
-#include "gs-application.h"
 
 #include <gdesktop-enums.h>
 #include <langinfo.h>
@@ -47,7 +46,6 @@ typedef enum {
 	GS_SHELL_UPDATES_STATE_ACTION_REFRESH_HAS_UPDATES,
 	GS_SHELL_UPDATES_STATE_ACTION_GET_UPDATES,
 	GS_SHELL_UPDATES_STATE_NO_UPDATES,
-	GS_SHELL_UPDATES_STATE_MANAGED,
 	GS_SHELL_UPDATES_STATE_HAS_UPDATES,
 	GS_SHELL_UPDATES_STATE_FAILED,
 	GS_SHELL_UPDATES_STATE_LAST,
@@ -236,7 +234,6 @@ gs_shell_updates_update_ui_state (GsShellUpdates *shell_updates)
 		break;
 	case GS_SHELL_UPDATES_STATE_ACTION_REFRESH_HAS_UPDATES:
 	case GS_SHELL_UPDATES_STATE_NO_UPDATES:
-	case GS_SHELL_UPDATES_STATE_MANAGED:
 	case GS_SHELL_UPDATES_STATE_HAS_UPDATES:
 	case GS_SHELL_UPDATES_STATE_FAILED:
 		gs_stop_spinner (GTK_SPINNER (priv->spinner_updates));
@@ -268,7 +265,6 @@ gs_shell_updates_update_ui_state (GsShellUpdates *shell_updates)
 		break;
 	case GS_SHELL_UPDATES_STATE_ACTION_REFRESH_HAS_UPDATES:
 	case GS_SHELL_UPDATES_STATE_NO_UPDATES:
-	case GS_SHELL_UPDATES_STATE_MANAGED:
 	case GS_SHELL_UPDATES_STATE_HAS_UPDATES:
 	case GS_SHELL_UPDATES_STATE_FAILED:
 		break;
@@ -287,7 +283,6 @@ gs_shell_updates_update_ui_state (GsShellUpdates *shell_updates)
 	case GS_SHELL_UPDATES_STATE_ACTION_REFRESH_NO_UPDATES:
 	case GS_SHELL_UPDATES_STATE_ACTION_GET_UPDATES:
 	case GS_SHELL_UPDATES_STATE_NO_UPDATES:
-	case GS_SHELL_UPDATES_STATE_MANAGED:
 	case GS_SHELL_UPDATES_STATE_HAS_UPDATES:
 	case GS_SHELL_UPDATES_STATE_STARTUP:
 	case GS_SHELL_UPDATES_STATE_FAILED:
@@ -311,7 +306,6 @@ gs_shell_updates_update_ui_state (GsShellUpdates *shell_updates)
 		break;
 	case GS_SHELL_UPDATES_STATE_ACTION_GET_UPDATES:
 	case GS_SHELL_UPDATES_STATE_STARTUP:
-	case GS_SHELL_UPDATES_STATE_MANAGED:
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_refresh"));
 		gtk_widget_hide (widget);
 		break;
@@ -345,7 +339,6 @@ gs_shell_updates_update_ui_state (GsShellUpdates *shell_updates)
 	case GS_SHELL_UPDATES_STATE_ACTION_REFRESH_NO_UPDATES:
 	case GS_SHELL_UPDATES_STATE_ACTION_GET_UPDATES:
 	case GS_SHELL_UPDATES_STATE_NO_UPDATES:
-	case GS_SHELL_UPDATES_STATE_MANAGED:
 	case GS_SHELL_UPDATES_STATE_FAILED:
 		gtk_widget_hide (widget);
 		break;
@@ -387,9 +380,6 @@ gs_shell_updates_update_ui_state (GsShellUpdates *shell_updates)
 	case GS_SHELL_UPDATES_STATE_ACTION_REFRESH_HAS_UPDATES:
 		gtk_stack_set_visible_child_name (GTK_STACK (priv->stack_updates), "view");
 		break;
-	case GS_SHELL_UPDATES_STATE_MANAGED:
-		gtk_stack_set_visible_child_name (GTK_STACK (priv->stack_updates), "managed");
-		break;
 	case GS_SHELL_UPDATES_STATE_FAILED:
 		gtk_stack_set_visible_child_name (GTK_STACK (priv->stack_updates), "failed");
 		break;
@@ -421,8 +411,6 @@ gs_shell_updates_set_state (GsShellUpdates *shell_updates,
 			    GsShellUpdatesState state)
 {
 	shell_updates->priv->state = state;
-	if (gs_updates_are_managed ())
-		shell_updates->priv->state = GS_SHELL_UPDATES_STATE_MANAGED;
 	gs_shell_updates_update_ui_state (shell_updates);
 }
 
@@ -461,7 +449,7 @@ gs_shell_updates_get_updates_cb (GsPluginLoader *plugin_loader,
 	}
 
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_updates_counter"));
-	if (list != NULL && !gs_updates_are_managed ()) {
+	if (list != NULL) {
 		_cleanup_free_ gchar *text = NULL;
 		text = g_strdup_printf ("%d", g_list_length (list));
 		gtk_label_set_label (GTK_LABEL (widget), text);
@@ -582,7 +570,7 @@ show_update_details (GsApp *app, GsShellUpdates *shell_updates)
 	GsShellUpdatesPrivate *priv = shell_updates->priv;
 	GtkWidget *dialog;
 
-	dialog = gs_update_dialog_new ();
+	dialog = gs_update_dialog_new (priv->plugin_loader);
 	gs_update_dialog_show_update_details (GS_UPDATE_DIALOG (dialog), app);
 
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), gs_shell_get_window (priv->shell));
@@ -847,18 +835,47 @@ gs_offline_updates_cancel (void)
 		g_warning ("failed to cancel the offline update: %s", error->message);
 }
 
+/**
+ * gs_shell_updates_upgrade_cb:
+ **/
 static void
-gs_shell_updates_button_update_all_cb (GtkButton      *button,
-				       GsShellUpdates *updates)
+gs_shell_updates_upgrade_cb (GsPluginLoader *plugin_loader,
+			     GAsyncResult *res,
+			     GsShellUpdates *shell_updates)
 {
 	_cleanup_error_free_ GError *error = NULL;
-	if (!pk_offline_trigger (PK_OFFLINE_ACTION_REBOOT, NULL, &error)) {
-		g_warning ("failed to trigger an offline update: %s", error->message);
+
+	/* get the results */
+	if (!gs_plugin_loader_app_action_finish (plugin_loader, res, &error)) {
+		g_warning ("Failed to upgrade: %s", error->message);
 		return;
 	}
 	gs_reboot (gs_offline_updates_cancel);
 }
 
+static void
+gs_shell_updates_button_update_all_cb (GtkButton      *button,
+				       GsShellUpdates *shell_updates)
+{
+	GsApp *app;
+	GsShellUpdatesPrivate *priv = shell_updates->priv;
+	guint i;
+	_cleanup_error_free_ GError *error = NULL;
+	_cleanup_ptrarray_unref_ GPtrArray *apps = NULL;
+
+	/* do the upgrade action? */
+	apps = gs_update_list_get_apps (GS_UPDATE_LIST (priv->list_box_updates));
+	for (i = 0; i < apps->len; i++) {
+		app = g_ptr_array_index (apps, i);
+		gs_plugin_loader_app_action_async (priv->plugin_loader,
+						   app,
+						   GS_PLUGIN_LOADER_ACTION_UPGRADE,
+						   priv->cancellable,
+						   (GAsyncReadyCallback) gs_shell_updates_upgrade_cb,
+						   shell_updates);
+	}
+}
+
 /**
  * gs_shell_updates_get_properties_cb:
  **/
@@ -891,32 +908,6 @@ gs_shell_updates_status_changed_cb (GsPluginLoader *plugin_loader,
 	gs_shell_updates_update_ui_state (shell_updates);
 }
 
-static void
-on_permission_changed (GPermission *permission,
-                       GParamSpec  *pspec,
-                       gpointer     data)
-{
-        GsShellUpdates *shell_updates = data;
-        GsShellUpdatesPrivate *priv = shell_updates->priv;
-
-	if (gs_updates_are_managed()) {
-		gs_shell_updates_set_state (shell_updates, GS_SHELL_UPDATES_STATE_MANAGED);
-	}
-	else if (priv->state == GS_SHELL_UPDATES_STATE_MANAGED) {
-		gs_shell_updates_set_state (shell_updates, GS_SHELL_UPDATES_STATE_NO_UPDATES);
-	}
-}
-
-static void
-gs_shell_updates_monitor_permission (GsShellUpdates *shell_updates)
-{
-        GPermission *permission;
-
-        permission = gs_offline_updates_permission_get ();
-        g_signal_connect (permission, "notify",
-                          G_CALLBACK (on_permission_changed), shell_updates);
-}
-
 void
 gs_shell_updates_setup (GsShellUpdates *shell_updates,
 			GsShell *shell,
@@ -960,8 +951,6 @@ gs_shell_updates_setup (GsShellUpdates *shell_updates,
 			  G_CALLBACK (gs_shell_updates_button_network_settings_cb),
 			  shell_updates);
 
-	gs_shell_updates_monitor_permission (shell_updates);
-
 	g_signal_connect (priv->control, "notify::network-state",
 			  G_CALLBACK (gs_shell_updates_notify_network_state_cb),
 			  shell_updates);
