@@ -37,7 +37,6 @@
 #include "gs-shell-extras.h"
 #include "gs-sources-dialog.h"
 #include "gs-update-dialog.h"
-#include "gs-offline-updates.h"
 
 static const gchar *page_name[] = {
 	"overview",
@@ -175,8 +174,6 @@ gs_shell_change_mode (GsShell *shell,
 
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_updates"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), mode == GS_SHELL_MODE_UPDATES);
-	gtk_widget_set_visible (widget, !gs_updates_are_managed() || mode == GS_SHELL_MODE_UPDATES);
-
 	priv->ignore_primary_buttons = FALSE;
 
 	/* switch page */
@@ -522,29 +519,6 @@ gs_shell_main_window_mapped_cb (GtkWidget *widget, GsShell *shell)
 				    gtk_widget_get_scale_factor (widget));
 }
 
-static void
-on_permission_changed (GPermission *permission,
-                       GParamSpec  *pspec,
-                       gpointer     data)
-{
-        GsShell *shell = data;
-	GsShellPrivate *priv = shell->priv;
-	GtkWidget *widget;
-
-	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_updates"));
-	gtk_widget_set_visible (widget, !gs_updates_are_managed() || priv->mode == GS_SHELL_MODE_UPDATES);
-}
-
-static void
-gs_shell_monitor_permission (GsShell *shell)
-{
-        GPermission *permission;
-
-        permission = gs_offline_updates_permission_get ();
-        g_signal_connect (permission, "notify",
-                          G_CALLBACK (on_permission_changed), shell);
-}
-
 /**
  * gs_shell_setup:
  */
@@ -561,8 +535,6 @@ gs_shell_setup (GsShell *shell, GsPluginLoader *plugin_loader, GCancellable *can
 			  G_CALLBACK (gs_shell_updates_changed_cb), shell);
 	priv->cancellable = g_object_ref (cancellable);
 
-	gs_shell_monitor_permission (shell);
-
 	/* get UI */
 	priv->builder = gtk_builder_new_from_resource ("/org/gnome/Software/gnome-software.ui");
 	priv->main_window = GTK_WINDOW (gtk_builder_get_object (priv->builder, "window_software"));
@@ -705,60 +677,17 @@ gs_shell_get_mode_string (GsShell *shell)
 	return page_name[priv->mode];
 }
 
-static void
-gs_shell_get_installed_updates_cb (GsPluginLoader *plugin_loader,
-				   GAsyncResult *res,
-				   GsShell *shell)
-{
-	GsShellPrivate *priv = shell->priv;
-	GList *list;
-	GtkWidget *dialog;
-	_cleanup_error_free_ GError *error = NULL;
-
-	/* get the results */
-	list = gs_plugin_loader_get_updates_finish (plugin_loader, res, &error);
-	if (list == NULL) {
-		if (g_error_matches (error,
-				     GS_PLUGIN_LOADER_ERROR,
-				     GS_PLUGIN_LOADER_ERROR_NO_RESULTS)) {
-			g_debug ("no updates to show");
-		} else if (g_error_matches (error,
-					    G_IO_ERROR,
-					    G_IO_ERROR_CANCELLED)) {
-			g_debug ("get updates cancelled");
-		} else {
-			g_warning ("failed to get updates: %s", error->message);
-		}
-		goto out;
-	}
-
-	dialog = gs_update_dialog_new ();
-	gs_update_dialog_show_installed_updates (GS_UPDATE_DIALOG (dialog), list);
-
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), priv->main_window);
-	gtk_window_present (GTK_WINDOW (dialog));
-
-out:
-	gs_plugin_list_free (list);
-}
-
-
 void
 gs_shell_show_installed_updates (GsShell *shell)
 {
 	GsShellPrivate *priv = shell->priv;
-	guint64 refine_flags;
+	GtkWidget *dialog;
 
-	refine_flags = GS_PLUGIN_REFINE_FLAGS_DEFAULT |
-		       GS_PLUGIN_REFINE_FLAGS_REQUIRE_UPDATE_DETAILS |
-		       GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION |
-		       GS_PLUGIN_REFINE_FLAGS_USE_HISTORY;
+	dialog = gs_update_dialog_new (priv->plugin_loader);
+	gs_update_dialog_show_installed_updates (GS_UPDATE_DIALOG (dialog));
 
-	gs_plugin_loader_get_updates_async (priv->plugin_loader,
-					    refine_flags,
-					    priv->cancellable,
-					    (GAsyncReadyCallback) gs_shell_get_installed_updates_cb,
-					    shell);
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), priv->main_window);
+	gtk_window_present (GTK_WINDOW (dialog));
 }
 
 void
