@@ -66,11 +66,6 @@ gs_plugin_destroy (GsPlugin *plugin)
 	g_object_unref (plugin->priv->task);
 }
 
-typedef struct {
-	GsApp		*app;
-	GsPlugin	*plugin;
-} ProgressData;
-
 /**
  * gs_plugin_packagekit_progress_cb:
  **/
@@ -79,37 +74,28 @@ gs_plugin_packagekit_progress_cb (PkProgress *progress,
 				  PkProgressType type,
 				  gpointer user_data)
 {
-	ProgressData *data = (ProgressData *) user_data;
-	GsPlugin *plugin = data->plugin;
+	GsPluginStatus plugin_status;
+	PkStatusEnum status;
+	GsPlugin *plugin = GS_PLUGIN (user_data);
 
-	if (type == PK_PROGRESS_TYPE_STATUS) {
-		GsPluginStatus plugin_status;
-		PkStatusEnum status;
-		g_object_get (progress,
-			      "status", &status,
-			      NULL);
+	if (type != PK_PROGRESS_TYPE_STATUS)
+		return;
+	g_object_get (progress,
+		      "status", &status,
+		      NULL);
 
-		/* profile */
-		if (status == PK_STATUS_ENUM_SETUP) {
-			gs_profile_start (plugin->profile,
-					  "packagekit-refine::transaction");
-		} else if (status == PK_STATUS_ENUM_FINISHED) {
-			gs_profile_stop (plugin->profile,
-					 "packagekit-refine::transaction");
-		}
-
-		plugin_status = packagekit_status_enum_to_plugin_status (status);
-		if (plugin_status != GS_PLUGIN_STATUS_UNKNOWN)
-			gs_plugin_status_update (plugin, NULL, plugin_status);
-
-	} else if (type == PK_PROGRESS_TYPE_PERCENTAGE) {
-		gint percentage;
-		g_object_get (progress,
-			      "percentage", &percentage,
-			      NULL);
-		if (percentage >= 0 && percentage <= 100)
-			gs_plugin_progress_update (plugin, data->app, percentage);
+	/* profile */
+	if (status == PK_STATUS_ENUM_SETUP) {
+		gs_profile_start (plugin->profile,
+				  "packagekit-refine::transaction");
+	} else if (status == PK_STATUS_ENUM_FINISHED) {
+		gs_profile_stop (plugin->profile,
+				 "packagekit-refine::transaction");
 	}
+
+	plugin_status = packagekit_status_enum_to_plugin_status (status);
+	if (plugin_status != GS_PLUGIN_STATUS_UNKNOWN)
+		gs_plugin_status_update (plugin, NULL, plugin_status);
 }
 
 /**
@@ -122,12 +108,8 @@ gs_plugin_add_installed (GsPlugin *plugin,
 			 GError **error)
 {
 	PkBitfield filter;
-	ProgressData data;
 	_cleanup_object_unref_ PkResults *results = NULL;
 
-	data.app = NULL;
-	data.plugin = plugin;
-
 	/* update UI as this might take some time */
 	gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_WAITING);
 
@@ -141,7 +123,7 @@ gs_plugin_add_installed (GsPlugin *plugin,
 	results = pk_client_get_packages (PK_CLIENT(plugin->priv->task),
 					  filter,
 					  cancellable,
-					  gs_plugin_packagekit_progress_cb, &data,
+					  gs_plugin_packagekit_progress_cb, plugin,
 					  error);
 	if (results == NULL)
 		return FALSE;
@@ -164,14 +146,10 @@ gs_plugin_add_sources_related (GsPlugin *plugin,
 	GsApp *app;
 	GsApp *app_tmp;
 	PkBitfield filter;
-	ProgressData data;
 	const gchar *id;
 	gboolean ret = TRUE;
 	_cleanup_object_unref_ PkResults *results = NULL;
 
-	data.app = NULL;
-	data.plugin = plugin;
-
 	gs_profile_start (plugin->profile, "packagekit::add-sources-related");
 	filter = pk_bitfield_from_enums (PK_FILTER_ENUM_INSTALLED,
 					 PK_FILTER_ENUM_NEWEST,
@@ -181,7 +159,7 @@ gs_plugin_add_sources_related (GsPlugin *plugin,
 	results = pk_client_get_packages (PK_CLIENT(plugin->priv->task),
 					   filter,
 					   cancellable,
-					   gs_plugin_packagekit_progress_cb, &data,
+					   gs_plugin_packagekit_progress_cb, plugin,
 					   error);
 	if (results == NULL) {
 		ret = FALSE;
@@ -224,16 +202,12 @@ gs_plugin_add_sources (GsPlugin *plugin,
 {
 	PkBitfield filter;
 	PkRepoDetail *rd;
-	ProgressData data;
 	const gchar *id;
 	guint i;
 	_cleanup_hashtable_unref_ GHashTable *hash = NULL;
 	_cleanup_object_unref_ PkResults *results = NULL;
 	_cleanup_ptrarray_unref_ GPtrArray *array = NULL;
 
-	data.app = NULL;
-	data.plugin = plugin;
-
 	/* ask PK for the repo details */
 	filter = pk_bitfield_from_enums (PK_FILTER_ENUM_NOT_SOURCE,
 					 PK_FILTER_ENUM_NOT_SUPPORTED,
@@ -242,13 +216,12 @@ gs_plugin_add_sources (GsPlugin *plugin,
 	results = pk_client_get_repo_list (PK_CLIENT(plugin->priv->task),
 					   filter,
 					   cancellable,
-					   gs_plugin_packagekit_progress_cb, &data,
+					   gs_plugin_packagekit_progress_cb, plugin,
 					   error);
 	if (results == NULL)
 		return FALSE;
 	hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 	array = pk_results_get_repo_detail_array (results);
-#if PK_CHECK_VERSION(0,9,1)
 	for (i = 0; i < array->len; i++) {
 		_cleanup_object_unref_ GsApp *app = NULL;
 		rd = g_ptr_array_index (array, i);
@@ -268,7 +241,6 @@ gs_plugin_add_sources (GsPlugin *plugin,
 				     g_strdup (id),
 				     (gpointer) app);
 	}
-#endif
 
 	/* get every application on the system and add it as a related package
 	 * if it matches */
@@ -284,19 +256,15 @@ gs_plugin_app_source_enable (GsPlugin *plugin,
 			     GCancellable *cancellable,
 			     GError **error)
 {
-	ProgressData data;
 	_cleanup_object_unref_ PkResults *results = NULL;
 
-	data.app = NULL;
-	data.plugin = plugin;
-
 	/* do sync call */
 	gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_WAITING);
 	results = pk_client_repo_enable (PK_CLIENT (plugin->priv->task),
 					 gs_app_get_origin (app),
 					 TRUE,
 					 cancellable,
-					 gs_plugin_packagekit_progress_cb, &data,
+					 gs_plugin_packagekit_progress_cb, plugin,
 					 error);
 	return results != NULL;
 }
@@ -312,7 +280,6 @@ gs_plugin_app_install (GsPlugin *plugin,
 {
 	GPtrArray *addons;
 	GPtrArray *source_ids;
-	ProgressData data;
 	const gchar *package_id;
 	guint i, j;
 	_cleanup_object_unref_ PkError *error_code = NULL;
@@ -320,9 +287,6 @@ gs_plugin_app_install (GsPlugin *plugin,
 	_cleanup_ptrarray_unref_ GPtrArray *array_package_ids = NULL;
 	_cleanup_strv_free_ gchar **package_ids = NULL;
 
-	data.app = app;
-	data.plugin = plugin;
-
 	/* only process this app if was created by this plugin */
 	if (g_strcmp0 (gs_app_get_management_plugin (app), "PackageKit") != 0)
 		return TRUE;
@@ -350,7 +314,7 @@ gs_plugin_app_install (GsPlugin *plugin,
 		results = pk_task_install_packages_sync (plugin->priv->task,
 							 package_ids,
 							 cancellable,
-							 gs_plugin_packagekit_progress_cb, &data,
+							 gs_plugin_packagekit_progress_cb, plugin,
 							 error);
 		if (results == NULL) {
 			gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
@@ -417,7 +381,7 @@ gs_plugin_app_install (GsPlugin *plugin,
 		results = pk_task_install_packages_sync (plugin->priv->task,
 							 (gchar **) array_package_ids->pdata,
 							 cancellable,
-							 gs_plugin_packagekit_progress_cb, &data,
+							 gs_plugin_packagekit_progress_cb, plugin,
 							 error);
 		if (results == NULL)
 			return FALSE;
@@ -436,7 +400,7 @@ gs_plugin_app_install (GsPlugin *plugin,
 		results = pk_task_install_files_sync (plugin->priv->task,
 						      package_ids,
 						      cancellable,
-						      gs_plugin_packagekit_progress_cb, &data,
+						      gs_plugin_packagekit_progress_cb, plugin,
 						      error);
 		if (results == NULL)
 			return FALSE;
@@ -476,19 +440,15 @@ gs_plugin_app_source_disable (GsPlugin *plugin,
 			      GCancellable *cancellable,
 			      GError **error)
 {
-	ProgressData data;
 	_cleanup_object_unref_ PkResults *results = NULL;
 
-	data.app = NULL;
-	data.plugin = plugin;
-
 	/* do sync call */
 	gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_WAITING);
 	results = pk_client_repo_enable (PK_CLIENT (plugin->priv->task),
 					 gs_app_get_id (app),
 					 FALSE,
 					 cancellable,
-					 gs_plugin_packagekit_progress_cb, &data,
+					 gs_plugin_packagekit_progress_cb, plugin,
 					 error);
 	return results != NULL;
 }
@@ -502,14 +462,9 @@ gs_plugin_app_source_remove (GsPlugin *plugin,
 			     GCancellable *cancellable,
 			     GError **error)
 {
-#if PK_CHECK_VERSION(0,9,1)
-	ProgressData data;
 	_cleanup_error_free_ GError *error_local = NULL;
 	_cleanup_object_unref_ PkResults *results = NULL;
 
-	data.app = NULL;
-	data.plugin = plugin;
-
 	/* do sync call */
 	gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_WAITING);
 	results = pk_client_repo_remove (PK_CLIENT (plugin->priv->task),
@@ -517,7 +472,7 @@ gs_plugin_app_source_remove (GsPlugin *plugin,
 					 gs_app_get_id (app),
 					 TRUE,
 					 cancellable,
-					 gs_plugin_packagekit_progress_cb, &data,
+					 gs_plugin_packagekit_progress_cb, plugin,
 					 &error_local);
 	if (results == NULL) {
 		/* fall back to disabling it */
@@ -527,9 +482,6 @@ gs_plugin_app_source_remove (GsPlugin *plugin,
 						     cancellable, error);
 	}
 	return TRUE;
-#else
-	return gs_plugin_app_source_disable (plugin, app, cancellable, error);
-#endif
 }
 
 /**
@@ -543,16 +495,12 @@ gs_plugin_app_remove (GsPlugin *plugin,
 {
 	const gchar *package_id;
 	GPtrArray *source_ids;
-	ProgressData data;
 	guint i;
 	guint cnt = 0;
 	_cleanup_object_unref_ PkError *error_code = NULL;
 	_cleanup_object_unref_ PkResults *results = NULL;
 	_cleanup_strv_free_ gchar **package_ids = NULL;
 
-	data.app = NULL;
-	data.plugin = plugin;
-
 	/* only process this app if was created by this plugin */
 	if (g_strcmp0 (gs_app_get_management_plugin (app), "PackageKit") != 0)
 		return TRUE;
@@ -593,7 +541,7 @@ gs_plugin_app_remove (GsPlugin *plugin,
 						package_ids,
 						TRUE, FALSE,
 						cancellable,
-						gs_plugin_packagekit_progress_cb, &data,
+						gs_plugin_packagekit_progress_cb, plugin,
 						error);
 	if (results == NULL)
 		return FALSE;
@@ -626,12 +574,8 @@ gs_plugin_add_search_files (GsPlugin *plugin,
                             GError **error)
 {
 	PkBitfield filter;
-	ProgressData data;
 	_cleanup_object_unref_ PkResults *results = NULL;
 
-	data.app = NULL;
-	data.plugin = plugin;
-
 	/* do sync call */
 	gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_WAITING);
 	filter = pk_bitfield_from_enums (PK_FILTER_ENUM_NEWEST,
@@ -641,7 +585,7 @@ gs_plugin_add_search_files (GsPlugin *plugin,
 	                                  filter,
 	                                  search,
 	                                  cancellable,
-	                                  gs_plugin_packagekit_progress_cb, &data,
+	                                  gs_plugin_packagekit_progress_cb, plugin,
 	                                  error);
 	if (results == NULL)
 		return FALSE;
@@ -661,12 +605,8 @@ gs_plugin_add_search_what_provides (GsPlugin *plugin,
                                     GError **error)
 {
 	PkBitfield filter;
-	ProgressData data;
 	_cleanup_object_unref_ PkResults *results = NULL;
 
-	data.app = NULL;
-	data.plugin = plugin;
-
 	/* do sync call */
 	gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_WAITING);
 	filter = pk_bitfield_from_enums (PK_FILTER_ENUM_NEWEST,
@@ -676,7 +616,7 @@ gs_plugin_add_search_what_provides (GsPlugin *plugin,
 	                                   filter,
 	                                   search,
 	                                   cancellable,
-	                                   gs_plugin_packagekit_progress_cb, &data,
+	                                   gs_plugin_packagekit_progress_cb, plugin,
 	                                   error);
 	if (results == NULL)
 		return FALSE;
